@@ -2,12 +2,30 @@
 from __future__ import annotations
 
 import abc
+from collections import deque
 from typing import Any, Generic, Type, TypeVar, final
 
 
 class Event(abc.ABC):
     """Base class for events."""
 
+    parent_event: Event | None
+
+    def __init__(self, parent_event: Event | None) -> None:
+        """Add parent event for further tracking."""
+        self.parent_event = parent_event
+
+    def get_history(self) -> tuple[Event, ...]:
+        """Get history of events resulted current event to be emitted."""
+        history: deque[Event] = deque()
+
+        parent_event = self.parent_event
+        while parent_event is not None:
+            history.appendleft(parent_event)
+            parent_event = parent_event.parent_event
+
+        return tuple(history)
+
 
 @final
 class AllEvents:
